@@ -20,8 +20,6 @@ class BaseConverter(ABC):
             "PatientID",
             "PatientSex",
             "StudyInstanceUID",
-            "SeriesInstanceUID",
-            "SOPInstanceUID",
         ]
 
     def personalize_dcm(
@@ -78,6 +76,7 @@ class BaseConverter(ABC):
 
         ds.is_little_endian = True
         ds.is_implicit_VR = False
+        ds.SOPInstanceUID = generate_uid()
 
         # if we want to create the pdf with the pdf creation timing
         dt = datetime.datetime.now()
