@@ -1,14 +1,5 @@
-import datetime
 
 
-def generate_random_uid() -> str:
-    """Generate a dicom compatible UID
-
-    Returns:
-        [str]: the generated UId based on date and time
-    """
-    return "1.9.9." + str(datetime.datetime.now().strftime("%H%M%S%f%d%m%Y"))
-
 
 # Encapsulated PDF
 ENCAPS_PDF_MEDIA_SOP_CLASS_UID = "1.2.840.10008.5.1.4.1.1.104.1"
